@@ -88,8 +88,9 @@
 #' })
 #' RDP <- sample_dot_product(lpvs)
 #' embed <- embed_adjacency_matrix(RDP, 5)
+#' @family embedding
 #' @export
-embed_adjacency_matrix <- embed_adjacency_matrix
+embed_adjacency_matrix <- adjacency_spectral_embedding_impl
 
 
 #' Dimensionality selection for singular values using profile likelihood.
@@ -148,8 +149,9 @@ embed_adjacency_matrix <- embed_adjacency_matrix
 #' RDP.graph.3 <- sample_dot_product(lpvs.sph)
 #' dim_select(embed_adjacency_matrix(RDP.graph.3, 10)$D)
 #'
+#' @family embedding
 #' @export
-dim_select <- dim_select
+dim_select <- dim_select_impl
 
 
 #' Spectral Embedding of the Laplacian of a Graph
@@ -217,6 +219,7 @@ dim_select <- dim_select
 #' Consistent Adjacency Spectral Embedding for Stochastic Blockmodel Graphs,
 #' *Journal of the American Statistical Association*, Vol. 107(499), 2012
 #' @keywords graphs
+#' @export
 #' @examples
 #'
 #' ## A small graph
@@ -226,7 +229,8 @@ dim_select <- dim_select
 #' })
 #' RDP <- sample_dot_product(lpvs)
 #' embed <- embed_laplacian_matrix(RDP, 5)
-embed_laplacian_matrix <- embed_laplacian_matrix
+#' @family embedding
+embed_laplacian_matrix <- laplacian_spectral_embedding_impl
 
 
 #' Sample vectors uniformly from the surface of a sphere
@@ -264,9 +268,9 @@ sample_sphere_surface <- function(dim, n = 1, radius = 1, positive = TRUE) {
   radius <- as.numeric(radius)
   positive <- as.logical(positive)
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   # Function call
-  res <- .Call(C_R_igraph_sample_sphere_surface, dim, n, radius, positive)
+  res <- .Call(R_igraph_sample_sphere_surface, dim, n, radius, positive)
 
   res
 }
@@ -306,9 +310,9 @@ sample_sphere_volume <- function(dim, n = 1, radius = 1, positive = TRUE) {
   radius <- as.numeric(radius)
   positive <- as.logical(positive)
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   # Function call
-  res <- .Call(C_R_igraph_sample_sphere_volume, dim, n, radius, positive)
+  res <- .Call(R_igraph_sample_sphere_volume, dim, n, radius, positive)
 
   res
 }
@@ -341,9 +345,9 @@ sample_dirichlet <- function(n, alpha) {
   n <- as.integer(n)
   alpha <- as.numeric(alpha)
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   # Function call
-  res <- .Call(C_R_igraph_sample_dirichlet, n, alpha)
+  res <- .Call(R_igraph_sample_dirichlet, n, alpha)
 
   res
 }
