@@ -167,9 +167,7 @@ assign(".next", 1, .tkplot.env)
 #' }
 #'
 tkplot <- function(graph, canvas.width = 450, canvas.height = 450, ...) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   # Libraries
   requireNamespace("tcltk", quietly = TRUE) ||
