@@ -3,7 +3,7 @@ test_that("make_de_bruijn_graph works", {
   g2 <- make_de_bruijn_graph(2, 2)
   g3 <- make_line_graph(g)
 
-  expect_true(graph.isomorphic(g3, graph(c(
+  expect_true(graph.isomorphic(g3, make_graph(c(
     1, 1, 3, 1, 1, 2, 3, 2, 2, 3,
     4, 3, 2, 4, 4, 4
   ))))
